@@ -9,33 +9,33 @@
 ####
 ####   This file is part of the ParaMonte library.
 ####
-####   Permission is hereby granted, free of charge, to any person obtaining a 
-####   copy of this software and associated documentation files (the "Software"), 
-####   to deal in the Software without restriction, including without limitation 
-####   the rights to use, copy, modify, merge, publish, distribute, sublicense, 
-####   and/or sell copies of the Software, and to permit persons to whom the 
+####   Permission is hereby granted, free of charge, to any person obtaining a
+####   copy of this software and associated documentation files (the "Software"),
+####   to deal in the Software without restriction, including without limitation
+####   the rights to use, copy, modify, merge, publish, distribute, sublicense,
+####   and/or sell copies of the Software, and to permit persons to whom the
 ####   Software is furnished to do so, subject to the following conditions:
 ####
-####   The above copyright notice and this permission notice shall be 
+####   The above copyright notice and this permission notice shall be
 ####   included in all copies or substantial portions of the Software.
 ####
-####   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
-####   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
-####   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
-####   IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
-####   DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
-####   OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE 
+####   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+####   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+####   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+####   IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
+####   DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
+####   OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
 ####   OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 ####
 ####   ACKNOWLEDGMENT
 ####
 ####   ParaMonte is an honor-ware and its currency is acknowledgment and citations.
-####   As per the ParaMonte library license agreement terms, if you use any parts of 
-####   this library for any purposes, kindly acknowledge the use of ParaMonte in your 
-####   work (education/research/industry/development/...) by citing the ParaMonte 
+####   As per the ParaMonte library license agreement terms, if you use any parts of
+####   this library for any purposes, kindly acknowledge the use of ParaMonte in your
+####   work (education/research/industry/development/...) by citing the ParaMonte
 ####   library as described on this page:
 ####
-####       https://github.com/cdslaborg/paramonte/blob/master/ACKNOWLEDGMENT.md
+####       https://github.com/cdslaborg/paramonte/blob/main/ACKNOWLEDGMENT.md
 ####
 ####################################################################################################################################
 ####################################################################################################################################
@@ -72,7 +72,7 @@ class ParaMonteSampler:
 
             methodName
 
-                A string representing the name of the ParaMonte sampler 
+                A string representing the name of the ParaMonte sampler
                 that is to be instantiated.
 
         **Attributes**
@@ -118,8 +118,8 @@ class ParaMonteSampler:
 
                 **WARNING**
 
-                Specifying an input file will cause the sampler to ignore 
-                all other simulation specifications set by the user via 
+                Specifying an input file will cause the sampler to ignore
+                all other simulation specifications set by the user via
                 sampler instance's `spec`-component attributes.
 
             spec
@@ -133,7 +133,7 @@ class ParaMonteSampler:
                 If you need help on any of the simulation specifications, try
                 the supplied ``helpme()`` function in this component.
 
-                If you wish to reset some specifications to the default values, 
+                If you wish to reset some specifications to the default values,
                 simply set them to ``None``.
 
         **Methods**
@@ -257,8 +257,8 @@ class ParaMonteSampler:
         the user-provided input objective function ``getLogFuncRaw(ndim,point)`` is
         a C-style raw pointer. This requires the user to guarantee that ``point`` will
         be always used with array bounds in their implementation of the objective function.
-        The use of ``_runSampler()`` in place of ``runSampler()`` leads to a slight
-        performance gain in the simulations.
+        The use of ``_runSampler()`` in place of ``runSampler()`` might lead to a slight
+        performance gain in the simulations, that is often negligible.
 
             **Example serial usage**
 
@@ -368,21 +368,28 @@ class ParaMonteSampler:
 
         buildMode = "release" if self.buildMode is None else self.buildMode
 
-        stype = None
+        cstype = None
         dummyList = None
+        parallelism = None
         errorOccurred = True
         if isinstance(buildMode,str):
             errorOccurred = False
             if "-" in buildMode:
-                dummyList = buildMode.split("-")
-                buildMode = dummyList[0] # build type
-                stype = dummyList[1] # compiler suite
+                dummyList = buildMode.lower().split("-")
+                for item in dummyList:
+                    if item in ["debug","testing","release"]:
+                        buildMode = item
+                    elif item in ["impi","mpich","openmpi"]:
+                        parallelism = "_" + item
+                    elif item in ["intel","gnu"]:
+                        cstype = item
+                    else:
+                        errorOccurred = True
+                        break
 
-        if not errorOccurred: errorOccurred = buildMode not in ["release", "testing", "debug"]
-        if not errorOccurred and stype is not None: errorOccurred = not (stype=="gnu" or stype=="intel")
         if errorOccurred:
             if dummyList is not None: buildMode = "-".join(dummyList)
-            pm.abort( msg   = "The object attribute ``buildMode`` must be of type ``str``." + newline
+            pm.abort( msg   = "The object's attribute ``buildMode`` must be of type ``str``." + newline
                             + "It is an optional string argument with default value \"release\"." + newline
                             + "possible choices are:" + newline
                             + newline
@@ -421,22 +428,6 @@ class ParaMonteSampler:
 
         inputFileVec_pntr, inputFileLen = self._getInputFile(inputFile)
 
-        if self.mpiEnabled:
-            parallelism = "_mpi"
-        else:
-            parallelism = ""
-            pm.note( msg   = "Running the " + self._methodName + " sampler in serial mode..." + newline
-                            + "To run the " + self._methodName + " sampler in parallel mode visit:" + newline
-                            + newline
-                            + "    " + pm.website.home.url + newline
-                            + newline
-                            + "If you are using Jupyter notebook, check the Jupyter's " + newline
-                            + "terminal window for realtime simulation progress and report."
-                    , methodName = self._methodName
-                    , marginTop = 1
-                    , marginBot = 1
-                    )
-
         #if len(sys.argv)>1:
         #    if sys.argv[1]=="p":
         #        pm.note( msg = Running sampler in parallel mode...
@@ -464,71 +455,52 @@ class ParaMonteSampler:
 
         sys.stdout.flush()
 
-        #### setup env
+        #if pm.platform.isLinux:
+        #    from _pmreqs import getLocalInstallDir
+        #    localInstallDir = getLocalInstallDir()
+        #
+        #    if localInstallDir.gnu.root is not None:
+        #        for object in os.scandir(localInstallDir.gnu.root):
+        #            if object.is_dir() and ("lib" in object.name) and object not in os.environ["LD_LIBRARY_PATH"]:
+        #                os.environ["LD_LIBRARY_PATH"] = object.path + os.pathsep + os.environ["LD_LIBRARY_PATH"]
+        #    if localInstallDir.mpi.root is not None:
+        #        if localInstallDir.mpi.bin is not None:
+        #            if localInstallDir.mpi.bin not in os.environ["PATH"]: os.environ["PATH"] = localInstallDir.mpi.bin + os.pathsep + os.environ["PATH"]
+        #        for object in os.scandir(localInstallDir.mpi.root):
+        #            if object.is_dir() and ("lib" in object.name):
+        #                os.environ["LD_LIBRARY_PATH"] = object.path + os.pathsep + os.environ["LD_LIBRARY_PATH"]
+        #        if localInstallDir.mpi.lib is not None: os.environ["LD_LIBRARY_PATH"] = localInstallDir.mpi.lib + os.pathsep + os.environ["LD_LIBRARY_PATH"]
 
-        if pm.platform.isWin32:
+        #### determine the mpi library brand. @todo: This could be later moved to pmreqs as it does not need to be executed every time.
 
-            if "PATH" in os.environ:
-                os.environ["PATH"] = pm.path.root + os.pathsep + os.environ["PATH"]
+        if parallelism is None:
+            if self.mpiEnabled: 
+                import subprocess
+                cmdout = subprocess.getoutput("mpiexec --version").lower()
+                if "intel" in cmdout:
+                    parallelism = "_impi"
+                elif "hydra" in cmdout or "mpich" in cmdout:
+                    parallelism = "_mpich"
+                elif "openrte" in cmdout or "open-mpi" in cmdout or "openmpi" in cmdout:
+                    parallelism = "_openmpi"
+                else: # assume defaults
+                    if self.platform.isWin32 or self.platform.isLinux:
+                        parallelism = "_impi"
+                    elif self.platform.isMacOS:
+                        parallelism = "_openmpi"
             else:
-                os.environ["PATH"] = pm.path.root
-
-            #mpiFound = False
-            pathList = os.environ["PATH"].split(";")
-            for path in pathList:
-                pathLower = path.lower().replace("\\","")
-                if ("mpiintel64bin" in pathLower):
-                    #mpiFound = True
-                    #bldMode = buildMode
-                    #if bldMode=="testing": bldMode = "release"
-                    mpiPath = os.path.join(path,"release")
-                    os.environ["PATH"] = mpiPath + os.pathsep + os.environ["PATH"]
-                    libfabricPath = os.path.join(os.path.dirname(path),"libfabric","bin")
-                    os.environ["PATH"] = libfabricPath + os.pathsep + os.environ["PATH"]
-                    break
-
-        else:
-
-            if "LD_LIBRARY_PATH" not in os.environ:
-                os.environ["LD_LIBRARY_PATH"] = "."
-                if self.reportEnabled and pm.platform.isLinux:
-                    pm.warn( msg   = "LD_LIBRARY_PATH environmental variable is not defined in " + newline
-                                    + "your Python session. Consider running the following command " + newline
-                                    + "in your Bash shell before reopening Python and using ParaMonte: " + newline
-                                    + newline
-                                    + "    export LD_LIBRARY_PATH=."
-                            , methodName = self._methodName
-                            , marginTop = 1
-                            , marginBot = 1
-                            )
-            libdir = "/usr/lib"
-            if os.path.isdir(libdir):
-                os.environ["LD_LIBRARY_PATH"]  = libdir + os.pathsep + os.environ["LD_LIBRARY_PATH"]
-            libdir = "/usr/local/lib"
-            if os.path.isdir(libdir):
-                os.environ["LD_LIBRARY_PATH"]  = libdir + os.pathsep + os.environ["LD_LIBRARY_PATH"]
-            libdir = "/usr/lib64"
-            if os.path.isdir(libdir):
-                os.environ["LD_LIBRARY_PATH"]  = libdir + os.pathsep + os.environ["LD_LIBRARY_PATH"]
-            libdir = "/usr/local/lib64"
-            if os.path.isdir(libdir):
-                os.environ["LD_LIBRARY_PATH"]  = libdir + os.pathsep + os.environ["LD_LIBRARY_PATH"]
-            os.environ["LD_LIBRARY_PATH"]  = pm.path.root + os.pathsep + os.environ["LD_LIBRARY_PATH"]
-
-            from _pmreqs import getLocalInstallDir
-            localInstallDir = getLocalInstallDir()
-
-            if localInstallDir.gnu.root is not None:
-                for object in os.scandir(localInstallDir.gnu.root):
-                    if object.is_dir() and ("lib" in object.name):
-                        os.environ["LD_LIBRARY_PATH"] = object.path + os.pathsep + os.environ["LD_LIBRARY_PATH"]
-
-            if localInstallDir.mpi.root is not None:
-                if localInstallDir.mpi.bin is not None: os.environ["PATH"] = localInstallDir.mpi.bin + os.pathsep + os.environ["PATH"]
-                for object in os.scandir(localInstallDir.mpi.root):
-                    if object.is_dir() and ("lib" in object.name):
-                        os.environ["LD_LIBRARY_PATH"] = object.path + os.pathsep + os.environ["LD_LIBRARY_PATH"]
-                if localInstallDir.mpi.lib is not None: os.environ["LD_LIBRARY_PATH"] = localInstallDir.mpi.lib + os.pathsep + os.environ["LD_LIBRARY_PATH"]
+                parallelism = ""
+                pm.note( msg    = "Running the " + self._methodName + " sampler in serial mode..." + newline
+                                + "To run the " + self._methodName + " sampler in parallel mode visit:" + newline
+                                + newline
+                                + "    " + pm.website.home.url + newline
+                                + newline
+                                + "If you are using Jupyter notebook, check the Jupyter's " + newline
+                                + "terminal window for realtime simulation progress and report."
+                        , methodName = self._methodName
+                        , marginTop = 1
+                        , marginBot = 1
+                        )
 
         # import ParaMonte dll define result (None) AND argument (pointer to a c function) type
 
@@ -536,15 +508,22 @@ class ParaMonteSampler:
         buildModeList.pop(buildModeList.index(buildMode))
         buildModeList.insert(0,buildMode)
         pmcsList = ["intel","gnu"]
-        if stype is not None:
-            pmcsList.pop(pmcsList.index(stype))
-            pmcsList.insert(0,stype)
 
-        libNameSuffix = parallelism +   { "windows" : ".dll"
-                                        , "cygwin"  : ".dll"
-                                        , "darwin"  : ".dylib"
-                                        , "linux"   : ".so"
-                                        }.get(pm.platform.osname, ".so")
+        if cstype is None:
+            if parallelism=="_impi":
+                cstype = "intel"
+            else:
+                cstype = "gnu"
+        else:
+            pmcsList.pop(pmcsList.index(cstype))
+            pmcsList.insert(0,cstype)
+
+        libNameSuffix = { "windows" : ".dll"
+                        , "cygwin"  : ".dll"
+                        , "mingw"   : ".dll"
+                        , "linux"   : ".so"
+                        , "darwin"  : ".dylib"
+                        }.get(pm.platform.osname, ".so")
 
         libPath = None
         libFound = False
@@ -554,19 +533,22 @@ class ParaMonteSampler:
 
             for pmcs in pmcsList:
 
-                libName = libNamePrefix + pmcs + "_" + buildMode + "_dynamic_heap" + libNameSuffix
-                libPath = find_library(libName)
-                if libPath is None: libPath = os.path.join( pm.path.root, libName )
+                #### Build the library name
 
+                libName = libNamePrefix + pmcs + "_" + buildMode + "_shared_heap" + parallelism + libNameSuffix
+                libPath = find_library(libName)
+                if libPath is None: libPath = os.path.join( pm.path.lib[pm.platform.arch][pmcs], libName )
                 libFound = os.path.isfile(libPath)
                 if libFound: break
 
-            if libFound: # check if lib file exists
+            # exist the loop if the library has been found
+
+            if libFound: 
                 break
             #else:
             #    if self.reportEnabled:
-            #        pm.warn( msg   = "ParaMonte dynamic library for the requested build mode " + buildMode + " not found." + newline
-            #                        + "Searching for ParaMonte dynamic library in other build modes..."
+            #        pm.warn( msg   = "The ParaMonte shared library for the requested build mode " + buildMode + " not found." + newline
+            #                        + "Searching for the ParaMonte shared library in other build modes..."
             #                , methodName = self._methodName
             #                , marginTop = 1
             #                , marginBot = 1
@@ -600,7 +582,7 @@ class ParaMonteSampler:
             else:
                 parallelMsg = "Please report this issue at:" + newline
 
-            pm.abort( msg   = "Exhausted all possible ParaMonte dynamic library search" + newline
+            pm.abort( msg   = "Exhausted all possible ParaMonte shared library search" + newline
                             + "names but could not find any compatible library." + newline
                             #+ "Last search:" + newline
                             #+ newline
@@ -746,7 +728,11 @@ class ParaMonteSampler:
            #while isLoaded(libPath):
            #    dlclose(pmdll._handle)
             try:
-                ct.dlclose(pmdll._handle)
+                #ct.dlclose(pmdll._handle)
+                _dlclose_func = ct.cdll.LoadLibrary('').dlclose
+                _dlclose_func.argtypes = [ct.c_void_p]
+                _dlclose_func(pmdll._handle)
+                del pmdll
             except:
                 if self.reportEnabled:
                     pm.warn ( msg   = "Failed to properly close the ParaMonte shared library file. " + newline
@@ -947,17 +933,17 @@ class ParaMonteSampler:
 
                     The path only needs to uniquely identify the simulation
                     to which the tabular file belongs. For example, specifying
-                    ``"./mydir/mysim"`` as input will lead to a search for a 
-                    file that begins with ``"mysim"`` and ends with the tabular file 
-                    name's prefix, such as, ``"_sample.txt"``, inside the directory 
-                    ``"./mydir/"``. If there are multiple files with such name, 
+                    ``"./mydir/mysim"`` as input will lead to a search for a
+                    file that begins with ``"mysim"`` and ends with the tabular file
+                    name's prefix, such as, ``"_sample.txt"``, inside the directory
+                    ``"./mydir/"``. If there are multiple files with such name,
                     then all of them will be read and returned as a list.
 
                     The path can be also a world wide web address.
 
                     If this input argument is not provided by the user, the
-                    value of the object attribute ``outputFileName`` will be 
-                    used instead. At least one of the two mentioned routes 
+                    value of the object attribute ``outputFileName`` will be
+                    used instead. At least one of the two mentioned routes
                     must provide the path to the tabular file otherwise,
                     this method will break by calling ``sys.exit()``.
 
@@ -983,19 +969,19 @@ class ParaMonteSampler:
 
                 renabled
 
-                    If set to ``False``, the contents of the file(s) will be 
+                    If set to ``False``, the contents of the file(s) will be
                     stored as a list in a (new) component of the object with a
-                    name that ends with the prefix ``List``. Otherwise, ``None`` 
-                    will be the return value of the method. If set to ``True``, 
+                    name that ends with the prefix ``List``. Otherwise, ``None``
+                    will be the return value of the method. If set to ``True``,
                     the reverse will done. The default value is ``False``.
 
             **Returns**
 
                 List
 
-                    A Python list of ``TabularFileContents`` objects, each 
-                    of which corresponds to the contents of a unique restart 
-                    file. The contents of each object is dependent on the 
+                    A Python list of ``TabularFileContents`` objects, each
+                    of which corresponds to the contents of a unique restart
+                    file. The contents of each object is dependent on the
                     type of the file that has been parsed.
 
         """
@@ -1137,7 +1123,7 @@ class ParaMonteSampler:
 
                     The path only needs to uniquely identify the simulation
                     to which the output file belongs. For example, specifying
-                    ``"./mydir/mysim"`` as input will lead to a search for a 
+                    ``"./mydir/mysim"`` as input will lead to a search for a
                     file that begins with ``"mysim"`` and ends with ``"_sample.txt"``
                     inside the directory ``"./mydir/"``. If there are multiple
                     files with such name, then all of them will be read
@@ -1155,10 +1141,10 @@ class ParaMonteSampler:
 
                     Optional input string representing the delimiter used in the
                     output output file. If it is not provided as input argument,
-                    the value of the corresponding output object's attribute 
-                    ``outputDelimiter`` will be used instead. If none of the two 
-                    are available, the default comma delimiter ``","`` will be 
-                    assumed and used. 
+                    the value of the corresponding output object's attribute
+                    ``outputDelimiter`` will be used instead. If none of the two
+                    are available, the default comma delimiter ``","`` will be
+                    assumed and used.
 
                 parseContents (optional)
 
@@ -1168,9 +1154,9 @@ class ParaMonteSampler:
 
                 renabled (optional)
 
-                    If set to ``False``, the contents of the file(s) will be 
-                    stored as a list in a (new) component of the ParaDRAM object 
-                    named ``sampleList`` and ``None`` will be the return value 
+                    If set to ``False``, the contents of the file(s) will be
+                    stored as a list in a (new) component of the ParaDRAM object
+                    named ``sampleList`` and ``None`` will be the return value
                     of the method. If set to ``True``, the reverse will done.
                     The default value is ``False``.
 
@@ -1178,8 +1164,8 @@ class ParaMonteSampler:
 
                 sampleList (optional)
 
-                    A Python list of ``TabularFileContents`` objects, each 
-                    of which corresponds to the contents of a unique restart 
+                    A Python list of ``TabularFileContents`` objects, each
+                    of which corresponds to the contents of a unique restart
                     file. Each object has the following components:
 
                         file
@@ -1192,7 +1178,7 @@ class ParaMonteSampler:
 
                         ndim
 
-                            The number of dimensions of the domain of the objective 
+                            The number of dimensions of the domain of the objective
                             function from which the output has been drawn.
 
                         count
@@ -1201,7 +1187,7 @@ class ParaMonteSampler:
 
                         plot
 
-                            A structure containing the graphics tools for the 
+                            A structure containing the graphics tools for the
                             visualization of the contents of the file.
 
                         df
@@ -1214,7 +1200,7 @@ class ParaMonteSampler:
                             corresponding to each column in the progress file, a property
                             with the same name as the column header is also created
                             for the object which contains the data stored in that column
-                            of the progress file. These properties are all stored in the 
+                            of the progress file. These properties are all stored in the
                             attribute ``contents``.
 
                 If ``renabled = True``, the list of objects will be returned as the
@@ -1276,10 +1262,10 @@ class ParaMonteSampler:
 
                     Optional input string representing the delimiter used in the
                     output output file. If it is not provided as input argument,
-                    the value of the corresponding output object's attribute 
-                    ``outputDelimiter`` will be used instead. If none of the two 
-                    are available, the default comma delimiter ``","`` will be 
-                    assumed and used. 
+                    the value of the corresponding output object's attribute
+                    ``outputDelimiter`` will be used instead. If none of the two
+                    are available, the default comma delimiter ``","`` will be
+                    assumed and used.
 
                 parseContents (optional)
 
@@ -1289,9 +1275,9 @@ class ParaMonteSampler:
 
                 renabled (optional)
 
-                    If set to ``False``, the contents of the file(s) will be 
-                    stored as a list in a (new) component of the ParaDRAM object 
-                    named ``chainList`` and ``None`` will be the return value 
+                    If set to ``False``, the contents of the file(s) will be
+                    stored as a list in a (new) component of the ParaDRAM object
+                    named ``chainList`` and ``None`` will be the return value
                     of the method. If set to ``True``, the reverse will done.
                     The default value is ``False``.
 
@@ -1299,8 +1285,8 @@ class ParaMonteSampler:
 
                 chainList (optional)
 
-                    A Python list of ``TabularFileContents`` objects, each 
-                    of which corresponds to the contents of a unique restart 
+                    A Python list of ``TabularFileContents`` objects, each
+                    of which corresponds to the contents of a unique restart
                     file. Each object has the following components:
 
                         file
@@ -1313,7 +1299,7 @@ class ParaMonteSampler:
 
                         ndim
 
-                            The number of dimensions of the domain of the objective 
+                            The number of dimensions of the domain of the objective
                             function from which the output has been drawn.
 
                         count
@@ -1322,7 +1308,7 @@ class ParaMonteSampler:
 
                         plot
 
-                            A structure containing the graphics tools for the 
+                            A structure containing the graphics tools for the
                             visualization of the contents of the file.
 
                         df
@@ -1335,7 +1321,7 @@ class ParaMonteSampler:
                             corresponding to each column in the progress file, a property
                             with the same name as the column header is also created
                             for the object which contains the data stored in that column
-                            of the progress file. These properties are all stored in the 
+                            of the progress file. These properties are all stored in the
                             attribute ``contents``.
 
                 If ``renabled = True``, the list of objects will be returned as the
@@ -1433,7 +1419,7 @@ class ParaMonteSampler:
 
                     plot
 
-                        A structure containing the graphics tools for the 
+                        A structure containing the graphics tools for the
                         visualization of the contents of the file.
 
                     df
@@ -1446,7 +1432,7 @@ class ParaMonteSampler:
                         corresponding to each column in the progress file, a property
                         with the same name as the column header is also created
                         for the object which contains the data stored in that column
-                        of the progress file. These properties are all stored in the 
+                        of the progress file. These properties are all stored in the
                         attribute ``contents``.
 
                 If ``renabled = True``, the list of objects will be returned as the
@@ -1472,38 +1458,38 @@ class ParaMonteSampler:
                     ) -> tp.List[RestartFileContents] :
         """
 
-        Return a list of the contents of a set of the simulation(s) 
-        output restart files whose names begin the user-provided input 
-        file prefix, or as specified by the input simulation specification 
-        ``SAMPLER.spec.outputFileName``, where SAMPLER can be an instance 
+        Return a list of the contents of a set of the simulation(s)
+        output restart files whose names begin the user-provided input
+        file prefix, or as specified by the input simulation specification
+        ``SAMPLER.spec.outputFileName``, where SAMPLER can be an instance
         of any one of the ParaMonte's sampler classes, such as ``ParaDRAM()``.
 
             **NOTE**
 
-            Only restart output files in **ASCII format** can be read 
-            via this method. The binary restart files are NOT meant to 
-            be parsed via this method. To request for ASCII restart 
-            output files in simulations, set the input simulation 
+            Only restart output files in **ASCII format** can be read
+            via this method. The binary restart files are NOT meant to
+            be parsed via this method. To request for ASCII restart
+            output files in simulations, set the input simulation
             specification
 
             .. code-block:: python
 
                 SAMPLER.spec.restartFileFormat = "ascii",
 
-            where ``SAMPLER`` can be an instance of any one of the 
+            where ``SAMPLER`` can be an instance of any one of the
             ParaMonte's sampler classes, such as ``ParaDRAM()``.
 
             **WARNING**
-            
+
             Avoid using this routine for very large long simulations.
-            Reading the full restart file of a large-scale simulation 
+            Reading the full restart file of a large-scale simulation
             problem can be extremely memory-intensive.
 
             **WARNING**
 
-            This method is to be only used for post-processing of the 
-            output restart file(s) of an already finished simulation. 
-            It is NOT meant to be called by all processes in parallel 
+            This method is to be only used for post-processing of the
+            output restart file(s) of an already finished simulation.
+            It is NOT meant to be called by all processes in parallel
             mode, although it is possible.
 
             **Parameters**
@@ -1513,7 +1499,7 @@ class ParaMonteSampler:
                     A string representing the path to the restart file with the
                     default value of []. The path only needs to uniquely identify
                     the name of the simulation to which the restart file belongs.
-                    For example, specifying ``"./mydir/mysim"`` as input will lead 
+                    For example, specifying ``"./mydir/mysim"`` as input will lead
                     to a search for a file that begins with ``"mysim"`` and ends with
                     ``"_restart.txt"`` inside the directory ``"./mydir/"``.
                     If there are multiple files with such name, then all of them
@@ -1546,9 +1532,9 @@ class ParaMonteSampler:
 
                 renabled (optional)
 
-                    If set to ``False``, the contents of the file(s) will be 
-                    stored as a list in a (new) component of the sampler object 
-                    named ``restartList`` and ``None`` will be the return value 
+                    If set to ``False``, the contents of the file(s) will be
+                    stored as a list in a (new) component of the sampler object
+                    named ``restartList`` and ``None`` will be the return value
                     of the method. If set to ``True``, the reverse will done.
                     The default value is ``False``.
 
@@ -1556,8 +1542,8 @@ class ParaMonteSampler:
 
                 restartList (optional)
 
-                    A Python list of ``RestartFileContents`` objects, each 
-                    of which corresponds to the contents of a unique restart 
+                    A Python list of ``RestartFileContents`` objects, each
+                    of which corresponds to the contents of a unique restart
                     file. Each object has the following components:
 
                         file
@@ -1566,7 +1552,7 @@ class ParaMonteSampler:
 
                         ndim
 
-                            The number of dimensions of the domain of the objective 
+                            The number of dimensions of the domain of the objective
                             function for which the restart file was generated.
 
                         count
@@ -1575,7 +1561,7 @@ class ParaMonteSampler:
 
                         plot
 
-                            A structure containing the graphics tools for the 
+                            A structure containing the graphics tools for the
                             visualization of the contents of the file.
 
                         df
@@ -1585,7 +1571,7 @@ class ParaMonteSampler:
 
                         contents
 
-                            A structure whose components contain the information 
+                            A structure whose components contain the information
                             retrieved about each of the entities in the file.
 
                         propNameList
@@ -1681,10 +1667,10 @@ class ParaMonteSampler:
         """
 
         Return a list of the contents of a set of the simulation(s) output
-        report files whose names begin the user-provided input file prefix, 
-        or as specified by the input simulation specification 
-        ``SAMPLER.spec.outputFileName``, where SAMPLER can be 
-        an instance of any one of the ParaMonte's sampler 
+        report files whose names begin the user-provided input file prefix,
+        or as specified by the input simulation specification
+        ``SAMPLER.spec.outputFileName``, where SAMPLER can be
+        an instance of any one of the ParaMonte's sampler
         classes, such as ``ParaDRAM()``.
 
         **NOTE**
@@ -1734,10 +1720,10 @@ class ParaMonteSampler:
 
                 renabled (optional)
 
-                    If set to ``False``, the contents of the file(s) will be 
+                    If set to ``False``, the contents of the file(s) will be
                     stored as a list in a (new) component of the object with a
-                    name that ends with the prefix ``List``. Otherwise, ``None`` 
-                    will be the return value of the method. If set to ``True``, 
+                    name that ends with the prefix ``List``. Otherwise, ``None``
+                    will be the return value of the method. If set to ``True``,
                     the reverse will done. The default value is ``False``.
 
             **Returns**
@@ -1848,8 +1834,8 @@ class ParaMonteSampler:
 
                 topic
 
-                    A string value that is the name of a component of the current 
-                    sample object for which help is needed. For example:  
+                    A string value that is the name of a component of the current
+                    sample object for which help is needed. For example:
 
                     Example usage:
 
